Arugula
=======

This is a sample Python 3 project from which to start new projects.
It demonstrates an initial project structure.


Develop
-------

To develop the source code locally, clone the repository.

Then create a virtual environment.  You can do this, for example, using
[pyvenv][venv].  Simply run the following from the repository root:

    $ pyvenv .pyvenv
    $ source .pyvenv/bin/activate

Alternatively, you can use virtualenv (and virtualenvwrapper).  See
also the recommendations in the ["Python Packaging User Guide"][pug].

Then install the source code in develop mode:

    $ pip install -e .


[pug]: https://packaging.python.org/en/latest/tutorial.html
[venv]: https://docs.python.org/3/library/venv.html
